@@ -54,7 +54,7 @@ Returns None if there is no next block."""
 
 	def get_progression(self):
 		if len(self.progressions) > 0:
-			p = self.progressions[self.p_counter]
+			p = self.get_prog()
 			self.p_counter += 1
 			if self.p_counter == len(self.progressions):
 				self.p_counter = 0
@@ -66,3 +66,6 @@ Returns None if there is no next block."""
 
 		return None
 
+	def get_prog(self):
+		return self.progressions[self.p_counter]
+
